Struct Gpiorstr
#[repr(transparent)]pub struct Gpiorstr(pub u32);Expand description
RCC I/O port reset register
Tuple Fields
0: u32Implementations
impl Gpiorstr
impl Gpiorstr
pub const fn set_gpioarst(&mut self, val: bool)
pub const fn set_gpioarst(&mut self, val: bool)
I/O port A reset This bit is set and cleared by software.
pub const fn set_gpiobrst(&mut self, val: bool)
pub const fn set_gpiobrst(&mut self, val: bool)
I/O port B reset This bit is set and cleared by software.
pub const fn set_gpiocrst(&mut self, val: bool)
pub const fn set_gpiocrst(&mut self, val: bool)
I/O port C reset This bit is set and cleared by software.
pub const fn set_gpiodrst(&mut self, val: bool)
pub const fn set_gpiodrst(&mut self, val: bool)
I/O port D reset This bit is set and cleared by software.
pub const fn set_gpiofrst(&mut self, val: bool)
pub const fn set_gpiofrst(&mut self, val: bool)
I/O port F reset This bit is set and cleared by software.